/*
 * Copyright (C) 2009 HBM Netherlands B.V.
 * Schutweg 15a
 * 5145 NP Waalwijk
 * The Netherlands
 * http://www.hbm.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#ifndef JSON_RPC_H
#define JSON_RPC_H

#include "GEN_DAQ_API.h"
#include "lib/parson.h"

typedef enum ValueType
{
    VT_double,
    VT_int,
    VT_string,
    VT_array
} ValueType;

typedef struct JsonRpcNamedParameter
{
    const char *key;
    enum ValueType vType;
    union Value
    {
        double dValue;
        int iValue;
        const char *sValue;
        float *arValue;
    } value;

} JsonRpcNamedParameter;

JsonRpcNamedParameter JsonRpcCreateNamedParameter(const char *key, const JSON_Value *value);
JsonRpcNamedParameter JsonRpcCreateDoubleNamedParameter(const char *key, double value);
JsonRpcNamedParameter JsonRpcCreateIntNamedParameter(const char *key, int value);
JsonRpcNamedParameter JsonRpcCreateStringNamedParameter(const char *key, const char *value);
JsonRpcNamedParameter JsonRpcCreateArrayParameter(const char *key, const JSON_Array *value);
const char *JsonRpcCreateRequest(const char *method, int requestID, JsonRpcNamedParameter *params, size_t numParams);
GHSReturnValue JsonRpcParseResponse(const char *message, int ExpectedRequestID, JsonRpcNamedParameter **params, size_t *numParams);

#endif /* JSON_RPC_H */
